##  Insights from Data Object Fact Sheet
  * Data classification of applications can be shown in a Matrix View (Aggregated View).
  * Visualization of data flow.
  * Application usage on CRUD can be shown in the data object landscape report leveraging the application landscape report.
